#ifndef NT2_INCLUDE_FUNCTIONS_LT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LT_HPP_INCLUDED

#include <nt2/operator/include/functions/lt.hpp>

#endif
